@@ -27,9 +27,6 @@ SM_RCSID("@(#)$Id: string.c,v 1.4 2013-11-22 20:51:43 ca Exp $")
 **
 **	Returns:
 **		none.
-**
-**	Side Effects:
-**		none.
 */
 
 void
@@ -54,3 +51,34 @@ stripquotes(s)
 		*q++ = c;
 	} while (c != '\0');
 }
+
+/*
+**  UNFOLDSTRIPQUOTES -- Strip quotes & quote bits from a string.
+**
+**	Parameters:
+**		s -- the string to strip.
+**
+**	Returns:
+**		none.
+*/
+
+void
+unfoldstripquotes(s)
+	char *s;
+{
+	char *p, *q, c;
+
+	if (s == NULL)
+		return;
+
+	p = q = s;
+	do
+	{
+		c = *p++;
+		if (c == '\\' || c == '\n')
+			c = *p++;
+		else if (c == '"')
+			continue;
+		*q++ = c;
+	} while (c != '\0');
+}
