@@ -61,15 +61,15 @@ struct bf
 	int	bf_buffilled;	/* Bytes of buffer actually filled */
 	char	*bf_filename;	/* Name of buffered file, if ever committed */
 	MODE_T	bf_filemode;	/* Mode of buffered file, if ever committed */
-	off_t	bf_offset;	/* Currect file offset */
+	off_t	bf_offset;	/* Current file offset */
 	int	bf_size;	/* Total current size of file */
 };
 
 #ifdef BF_STANDALONE
 # define OPEN(fn, omode, cmode, sff) open(fn, omode, cmode)
-#else /* BF_STANDALONE */
+#else
 # define OPEN(fn, omode, cmode, sff) safeopen(fn, omode, cmode, sff)
-#endif /* BF_STANDALONE */
+#endif
 
 struct bf_info
 {
@@ -566,7 +566,7 @@ sm_bfwrite(fp, buf, nbytes)
 				if (!(errno == ENOSPC
 #ifdef EDQUOT
 				      || errno == EDQUOT
-#endif /* EDQUOT */
+#endif
 				     ))
 					errno = EIO;
 
@@ -804,9 +804,9 @@ sm_bftruncate(fp)
 		/* XXX: Not much we can do except rewind it */
 		errno = EINVAL;
 		return -1;
-#else /* NOFTRUNCATE */
+#else
 		return ftruncate(bfp->bf_disk_fd, 0);
-#endif /* NOFTRUNCATE */
+#endif
 	}
 	return 0;
 }
