@@ -640,9 +640,6 @@ static struct mcifbits	MciFlags[] =
 	{ MCIF_SIZE,		"SIZE"		},
 	{ MCIF_8BITMIME,	"8BITMIME"	},
 	{ MCIF_7BIT,		"7BIT"		},
-#if _FFR_SAMEDOMAIN
-	{ MCIF_SAMEDOMAIN,	"SAMEDOMAIN"	},
-#endif
 	{ MCIF_INHEADER,	"INHEADER"	},
 	{ MCIF_CVT8TO7,		"CVT8TO7"	},
 	{ MCIF_DSN,		"DSN"		},
@@ -664,6 +661,10 @@ static struct mcifbits	MciFlags[] =
 #endif
 	{ MCIF_INLONGLINE,	"INLONGLINE"	},
 	{ MCIF_AUTH2,		"AUTH2"		},
+#if _FFR_SAMEDOMAIN
+	{ MCIF_SAMEDOMAIN_TA,	"SAMEDOMAIN_TA"	},
+	{ MCIF_SAMEDOMAIN_SE,	"SAMEDOMAIN_SE"	},
+#endif
 	{ MCIF_ONLY_EHLO,	"ONLY_EHLO"	},
 	{ MCIF_NOTSTICKY,	"NOTSTICKY"	},
 #if USE_EAI
