@@ -468,7 +468,11 @@ savemail(e, sendbody)
 
 		  case ESM_PANIC:
 			/* leave the locked queue & transcript files around */
+#if _FFR_SE_TA_ID
+			loseqfile(e, "stat=savemail panic, reason=cannot save rejected email anywhere");
+#else
 			loseqfile(e, "savemail panic");
+#endif
 			panic = true;
 			errno = 0;
 			syserr("554 savemail: cannot save rejected email anywhere");
@@ -555,6 +559,11 @@ returntosender(msg, returnq, flags, e)
 	macdefine(&ee->e_macro, A_PERM, 's', "localhost");
 	macdefine(&ee->e_macro, A_PERM, '_', "localhost");
 	clrsessenvelope(ee);
+#if _FFR_SE_TA_ID
+	if (NULL != e->e_s_ta)
+		ee->e_s_ta = sm_rpool_strdup_x(ee->e_rpool, e->e_s_ta);
+	/* e_s_se is not copied because it is not used/logged for delivery */
+#endif
 
 	ee->e_puthdr = putheader;
 	ee->e_putbody = errbody;
@@ -626,8 +635,14 @@ returntosender(msg, returnq, flags, e)
 			p = "postmaster notify";
 		else
 			p = "DSN";
+#if _FFR_SE_TA_ID
+		sm_syslog(LOG_INFO, e->e_id, S_TA_ID "=%s, qid=%s, "S_TA_ID "=%s, dsn_type=%s, stat=%s",
+			  e->e_s_ta, ee->e_id, ee->e_s_ta, p, shortenstring(msg, MAXSHORTSTR));
+
+#else
 		sm_syslog(LOG_INFO, e->e_id, "%s: %s: %s",
 			  ee->e_id, p, shortenstring(msg, MAXSHORTSTR));
+#endif
 	}
 
 	if (SendMIMEErrors)
