@@ -20,7 +20,7 @@ SM_RCSID("@(#)$Id: tls.c,v 8.127 2013-11-27 02:51:11 gshapiro Exp $")
 #  include <openssl/rand.h>
 # endif
 # include <openssl/engine.h>
-# if _FFR_TLS_ALTNAMES
+# if _FFR_TLS_ALTNAMES || _FFR_CERT_CHK
 #  include <openssl/x509v3.h>
 # endif
 # include <tls.h>
@@ -1008,6 +1008,9 @@ inittls(tls_ctx, req, options, srv, certfile, keyfile, cacertpath, cacertfile, d
 	long rt_version;
 	STACK_OF(SSL_COMP) *comp_methods;
 # endif
+# if _FFR_CERT_CHK
+	X509 *cert;
+# endif
 
 	status = TLS_S_NONE;
 	who = srv ? "server" : "client";
@@ -1332,6 +1335,23 @@ inittls(tls_ctx, req, options, srv, certfile, keyfile, cacertpath, cacertfile, d
 			return false;
 	}
 
+# if _FFR_CERT_CHK
+	cert = SSL_CTX_get0_certificate(*tls_ctx);
+	if (NULL != cert &&
+	    (r = X509_check_purpose(cert, srv ? X509_PURPOSE_SSL_SERVER
+					: X509_PURPOSE_SSL_CLIENT, 0)) <= 0)
+	{
+		/* the cert can be used, though it cannot be verified */
+		if (LogLevel > 7)
+		{
+			sm_syslog(LOG_WARNING, NOQID,
+				  "STARTTLS=%s, error: X509_check_purpose(%s) failed: %d",
+				  who, certfile, r);
+			tlslogerr(LOG_WARNING, 9, who);
+		}
+	}
+# endif /* _FFR_CERT_CHK */
+
 	/* XXX this code is pretty much duplicated from above! */
 
 	/* load private key */
@@ -2162,6 +2182,16 @@ tls_get_info(ssl, srv, host, mac, certreq
 	if (LogLevel > 8)
 	{
 		char *vers, *s1, *s2, *cbits, *algbits;
+# if _FFR_VRFY_STAT
+		const char *vrfystatus;
+
+		if (X509_V_OK != verifyok)
+			vrfystatus = X509_verify_cert_error_string(
+					SSL_get_verify_result(ssl));
+		else
+			vrfystatus = NULL;
+# define VRFYSTAT_COND	(NULL != vrfystatus)
+#endif
 
 		vers = macget(mac, macid("{tls_version}"));
 		cbits = macget(mac, macid("{cipher_bits}"));
@@ -2177,7 +2207,7 @@ tls_get_info(ssl, srv, host, mac, certreq
 # endif
 		/* XXX: maybe cut off ident info? */
 		sm_syslog(LOG_INFO, NOQID,
-			  "STARTTLS=%s%s%s, relay=%.100s, version=%.16s, verify=%.16s, cipher=%.64s, bits=%.6s/%.6s%s%s%s%s",
+			  "STARTTLS=%s%s%s, relay=%.100s, version=%.16s, verify=%.16s, cipher=%.64s, bits=%.6s/%.6s%s%s%s%s%s%s",
 			  who,
 #if _FFR_SE_TA_ID
 			(se_id != NULL) ? (srv ? ", " S_SE_ID "=" : ", " C_SE_ID "=") : "",
@@ -2204,6 +2234,12 @@ tls_get_info(ssl, srv, host, mac, certreq
 			  ? ", note=too many TLSA RRs" : ""
 # else
 			, "", "", "", ""
+# endif
+# if _FFR_VRFY_STAT
+			, VRFYSTAT_COND ? ", status=" : ""
+			, VRFYSTAT_COND ? vrfystatus : ""
+# else
+			, "", ""
 # endif
 			);
 
